@@ -26,8 +26,8 @@ Generic Access to Thruks Config
 
 ######################################
 
-our $VERSION = '3.25.20251031';
-our $GIT_HASH = "a7e3a3654"; # set by dailydist make target
+our $VERSION = '3.25.20251102';
+our $GIT_HASH = "d6a934ac6"; # set by dailydist make target
 
 our $config;
 our $project_root = home() || confess('could not determine project_root from inc.');
@@ -35,7 +35,7 @@ our $project_root = home() || confess('could not determine project_root from inc
 my $base_defaults = {
     'name'                                  => 'Thruk',
     'fileversion'                           => $VERSION,
-    'released'                              => 'October 31, 2025',
+    'released'                              => 'November 02, 2025',
     'compression_format'                    => 'gzip',
     'ENCODING'                              => 'utf-8',
     'image_path'                            => $project_root.'/root/thruk/images',
